@@ -7,11 +7,15 @@
 #include <glib/gi18n.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <unistd.h>
+#include <sys/ioctl.h>
 
+#include <linux/types.h>
 #ifdef HAVE_LINUX_FD_H
 #include <linux/fd.h>
 #endif
 
+#include <string.h>
 #include "gfloppy.h"
 #include "fdformat.h"
 
