@@ -61,8 +61,6 @@ struct _GdictDatabaseChooserPrivate
   GdictContext *context;
   gint results;
 
-  GtkTooltips *tips;
-  
   guint start_id;
   guint match_id;
   guint end_id;
@@ -179,9 +177,6 @@ gdict_database_chooser_finalize (GObject *gobject)
 
   g_object_unref (priv->store);
 
-  if (priv->tips)
-    g_object_unref (priv->tips);
-
   g_free (priv->current_db);
   
   G_OBJECT_CLASS (gdict_database_chooser_parent_class)->finalize (gobject);
@@ -351,9 +346,8 @@ gdict_database_chooser_constructor (GType                  type,
 		    chooser);
   gtk_box_pack_start (GTK_BOX (hbox), priv->refresh_button, FALSE, FALSE, 0);
   gtk_widget_show (priv->refresh_button);
-  gtk_tooltips_set_tip (priv->tips, priv->refresh_button,
-		  	_("Reload the list of available databases"),
-			NULL);
+  gtk_widget_set_tooltip_text (priv->refresh_button,
+                               _("Reload the list of available databases"));
 
   priv->clear_button = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (priv->clear_button),
@@ -364,9 +358,8 @@ gdict_database_chooser_constructor (GType                  type,
 		    chooser);
   gtk_box_pack_start (GTK_BOX (hbox), priv->clear_button, FALSE, FALSE, 0);
   gtk_widget_show (priv->clear_button);
-  gtk_tooltips_set_tip (priv->tips, priv->clear_button,
-		        _("Clear the list of available databases"),
-			NULL);
+  gtk_widget_set_tooltip_text (priv->clear_button,
+                               _("Clear the list of available databases"));
 
   gtk_box_pack_end (GTK_BOX (chooser), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
@@ -423,9 +416,6 @@ gdict_database_chooser_init (GdictDatabaseChooser *chooser)
 		                    G_TYPE_STRING, /* db_name */
 				    G_TYPE_STRING  /* db_desc */);
 
-  priv->tips = gtk_tooltips_new ();
-  g_object_ref_sink (G_OBJECT (priv->tips));
-
   priv->start_id = 0;
   priv->end_id = 0;
   priv->match_id = 0;
