@@ -61,8 +61,6 @@ struct _GdictAppletPrivate
   guint size;
   GtkOrientation orient;
   
-  GtkTooltips *tooltips;
-  
   GConfClient *gconf_client;
   guint notify_id;
   guint font_notify_id;
@@ -369,11 +367,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (bbox);
   
   button = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
-
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	button,
-		  	_("Clear the definitions found"),
-			NULL);
+  gtk_widget_set_tooltip_text (button, _("Clear the definitions found"));
   set_atk_name_description (button,
 		  	    _("Clear definition"),
 			    _("Clear the text of the definition"));
@@ -383,11 +377,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (button);
 
   button = gtk_button_new_from_stock (GTK_STOCK_PRINT);
-
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	button,
-			_("Print the definitions found"),
-			NULL);
+  gtk_widget_set_tooltip_text (button, _("Print the definitions found"));
   set_atk_name_description (button,
 		  	    _("Print definition"),
 			    _("Print the text of the definition"));
@@ -397,11 +387,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (button);
 
   button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
-  
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	button,
-			_("Save the definitions found"),
-			NULL);
+  gtk_widget_set_tooltip_text (button, _("Save the definitions found"));
   set_atk_name_description (button,
 		  	    _("Save definition"),
 			    _("Save the text of the definition to a file"));
@@ -551,14 +537,10 @@ gdict_applet_draw (GdictApplet *applet)
 
   /* toggle button */
   priv->toggle = gtk_toggle_button_new ();
-  
+  gtk_widget_set_tooltip_text (priv->toggle, _("Click to view the dictionary window"));
   set_atk_name_description (priv->toggle,
 			    _("Toggle dictionary window"),
 		  	    _("Show or hide the definition window"));
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	priv->toggle,
-		  	_("Click to view the dictionary window"),
-			NULL);
   
   gtk_button_set_relief (GTK_BUTTON (priv->toggle),
 		  	 GTK_RELIEF_NONE);
@@ -610,14 +592,10 @@ gdict_applet_draw (GdictApplet *applet)
 
   /* entry */
   priv->entry = gtk_entry_new ();
-  
+  gtk_widget_set_tooltip_text (priv->entry, _("Type the word you want to look up"));
   set_atk_name_description (priv->entry,
 		  	    _("Dictionary entry"),
 			    _("Look up words in dictionaries"));
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	priv->entry,
-			_("Type the word you want to look up"),
-			NULL);
   
   gtk_entry_set_editable (GTK_ENTRY (priv->entry), TRUE);
   gtk_entry_set_width_chars (GTK_ENTRY (priv->entry), 12);
@@ -1155,9 +1133,6 @@ gdict_applet_finalize (GObject *object)
   if (priv->loader)
     g_object_unref (priv->loader);
   
-  if (priv->tooltips)
-    g_object_unref (priv->tooltips);
-
   if (priv->icon)
     g_object_unref (priv->icon);
   
@@ -1205,7 +1180,7 @@ gdict_applet_init (GdictApplet *applet)
   gdict_source_loader_add_search_path (priv->loader, data_dir);
   g_free (data_dir);
   
-  gtk_window_set_default_icon_name ("gnome-dictionary");
+  gtk_window_set_default_icon_name ("accessories-dictionary");
   
   panel_applet_set_flags (PANEL_APPLET (applet),
 			  PANEL_APPLET_EXPAND_MINOR);
@@ -1282,15 +1257,11 @@ gdict_applet_init (GdictApplet *applet)
 #endif /* !GDICT_APPLET_STAND_ALONE */
 
   priv->icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		  			 "gnome-dictionary",
+		  			 "accessories-dictionary",
 					 48,
 					 0,
 					 NULL);
   
-  priv->tooltips = gtk_tooltips_new ();
-  g_object_ref (priv->tooltips);
-  gtk_object_sink (GTK_OBJECT (priv->tooltips));
-
   /* force first draw */
   gdict_applet_draw (applet);
 
