@@ -342,7 +342,8 @@ gdict_window_lookup_end_cb (GdictContext *context,
 
   /* search for similar words */
   gdict_speller_set_strategy (GDICT_SPELLER (window->speller), window->strategy);
-  gdict_speller_match (GDICT_SPELLER (window->speller), window->word);
+  if (window->word)
+    gdict_speller_match (GDICT_SPELLER (window->speller), window->word);
 
   gtk_list_store_append (window->completion_model, &iter);
   gtk_list_store_set (window->completion_model, &iter,
@@ -1234,18 +1235,22 @@ static void
 lookup_word (GdictWindow *window,
              gpointer     dummy)
 {
-  const gchar *word;
+  const gchar *entry_text;
+  gchar *word;
   
   g_assert (GDICT_IS_WINDOW (window));
   
   if (!window->context)
     return;
   
-  word = gtk_entry_get_text (GTK_ENTRY (window->entry));
-  if (!word || *word == '\0')
+  entry_text = gtk_entry_get_text (GTK_ENTRY (window->entry));
+  if (!entry_text || *entry_text == '\0')
     return;
 
-  gdict_window_set_word (window, word, NULL);
+  word = g_strdup (entry_text);
+  gdict_window_set_word (window, g_strstrip (word), NULL);
+
+  g_free (word);
 }
 
 static void
