@@ -36,6 +36,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <locale.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
@@ -57,7 +58,7 @@
 enum
 {
   COLUMN_NICK,
-  COLUMN_NAME,
+  COLUMN_LABEL,
   COLUMN_ID,
 
   N_COLUMNS
@@ -122,6 +123,7 @@ interactive_dialog_response_cb (GtkDialog *dialog,
       display_help (GTK_WINDOW (dialog));
       break;
     default:
+      gtk_widget_hide (GTK_WIDGET (dialog));
       break;
     }
 }
@@ -175,37 +177,49 @@ effect_combo_changed_cb (GtkComboBox *combo,
     }
 }
 
+typedef struct {
+  ScreenshotEffectType id;
+  const gchar *label;
+  const gchar *nick;
+} ScreenshotEffect;
+
+/* Translators:
+ * these are the names of the effects available which will be
+ * displayed inside a combo box in interactive mode for the user
+ * to chooser.
+ */
+static const ScreenshotEffect effects[] = {
+  { SCREENSHOT_EFFECT_NONE, N_("None"), "none" },
+  { SCREENSHOT_EFFECT_SHADOW, N_("Drop shadow"), "shadow" },
+  { SCREENSHOT_EFFECT_BORDER, N_("Border"), "border" }
+};
+
+static guint n_effects = G_N_ELEMENTS (effects);
+
 static GtkWidget *
 create_effects_combo (void)
 {
   GtkWidget *retval;
   GtkListStore *model;
-  GtkTreeIter iter;
   GtkCellRenderer *renderer;
+  gint i;
 
   model = gtk_list_store_new (N_COLUMNS,
                               G_TYPE_STRING,
                               G_TYPE_STRING,
                               G_TYPE_UINT);
+  
+  for (i = 0; i < n_effects; i++)
+    {
+      GtkTreeIter iter;
 
-  gtk_list_store_insert_with_values (model, &iter,
-                                     SCREENSHOT_EFFECT_NONE,
-                                     COLUMN_NAME, _("None"),
-                                     COLUMN_NICK, "none",
-                                     COLUMN_ID, SCREENSHOT_EFFECT_NONE,
-                                     -1);
-  gtk_list_store_insert_with_values (model, &iter,
-                                     SCREENSHOT_EFFECT_SHADOW,
-                                     COLUMN_NAME, _("Drop shadow"),
-                                     COLUMN_NICK, "shadow",
-                                     COLUMN_ID, SCREENSHOT_EFFECT_SHADOW,
-                                     -1);
-  gtk_list_store_insert_with_values (model, &iter,
-                                     SCREENSHOT_EFFECT_BORDER,
-                                     COLUMN_NAME, _("Border"),
-                                     COLUMN_NICK, "border",
-                                     COLUMN_ID, SCREENSHOT_EFFECT_BORDER,
-                                     -1);
+      gtk_list_store_insert (model, &iter, i);
+      gtk_list_store_set (model, &iter,
+                          COLUMN_ID, effects[i].id,
+                          COLUMN_LABEL, gettext (effects[i].label),
+                          COLUMN_NICK, effects[i].nick,
+                          -1);
+    }
 
   retval = gtk_combo_box_new ();
   gtk_combo_box_set_model (GTK_COMBO_BOX (retval),
@@ -229,11 +243,11 @@ create_effects_combo (void)
     default:
       break;
     }
-
+  
   renderer = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (retval), renderer, TRUE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (retval), renderer,
-                                  "text", COLUMN_NAME,
+                                  "text", COLUMN_LABEL,
                                   NULL);
 
   g_signal_connect (retval, "changed",
@@ -244,16 +258,20 @@ create_effects_combo (void)
 }
 
 static void
-create_effects_frame (GtkWidget   *main_vbox,
+create_effects_frame (GtkWidget   *outer_vbox,
                       const gchar *frame_title)
 {
-  GtkWidget *vbox, *hbox;
+  GtkWidget *main_vbox, *vbox, *hbox;
   GtkWidget *align;
   GtkWidget *label;
   GtkWidget *check;
   GtkWidget *combo;
   gchar *title;
 
+  main_vbox = gtk_vbox_new (FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (outer_vbox), main_vbox, FALSE, FALSE, 0);
+  gtk_widget_show (main_vbox);
+
   title = g_strconcat ("<b>", frame_title, "</b>", NULL);
   label = gtk_label_new (title);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -263,7 +281,7 @@ create_effects_frame (GtkWidget   *main_vbox,
   g_free (title);
 
   hbox = gtk_hbox_new (FALSE, 12);
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
   align = gtk_alignment_new (0.0, 0.0, 0.0, 0.0);
@@ -283,7 +301,7 @@ create_effects_frame (GtkWidget   *main_vbox,
   gtk_widget_show (vbox);
 
   /** Include window border **/
-  check = gtk_check_button_new_with_mnemonic (_("_Include the window border"));
+  check = gtk_check_button_new_with_mnemonic (_("Include the window _border"));
   gtk_widget_set_sensitive (check, take_window_shot);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), include_border);
   g_signal_connect (check, "toggled",
@@ -294,11 +312,11 @@ create_effects_frame (GtkWidget   *main_vbox,
   border_check = check;
 
   /** Effects **/
-  hbox = gtk_hbox_new (FALSE, 6);
+  hbox = gtk_hbox_new (FALSE, 12);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
-  label = gtk_label_new (_("Apply effect:"));
+  label = gtk_label_new_with_mnemonic (_("Apply _effect:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
@@ -306,15 +324,16 @@ create_effects_frame (GtkWidget   *main_vbox,
   combo = create_effects_combo ();
   gtk_widget_set_sensitive (combo, take_window_shot);
   gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
   gtk_widget_show (combo);
   effect_combo = combo;
 }
 
 static void
-create_screenshot_frame (GtkWidget   *main_vbox,
+create_screenshot_frame (GtkWidget   *outer_vbox,
                          const gchar *frame_title)
 {
-  GtkWidget *vbox, *hbox;
+  GtkWidget *main_vbox, *vbox, *hbox;
   GtkWidget *align;
   GtkWidget *radio;
   GtkWidget *image;
@@ -324,6 +343,10 @@ create_screenshot_frame (GtkWidget   *main_vbox,
   GSList *group;
   gchar *title;
 
+  main_vbox = gtk_vbox_new (FALSE, 6);
+  gtk_box_pack_start (GTK_BOX (outer_vbox), main_vbox, FALSE, FALSE, 0);
+  gtk_widget_show (main_vbox);
+
   title = g_strconcat ("<b>", frame_title, "</b>", NULL);
   label = gtk_label_new (title);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -333,7 +356,7 @@ create_screenshot_frame (GtkWidget   *main_vbox,
   g_free (title);
 
   hbox = gtk_hbox_new (FALSE, 12);
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
   align = gtk_alignment_new (0.0, 0.0, 0.0, 0.0);
@@ -382,7 +405,7 @@ create_screenshot_frame (GtkWidget   *main_vbox,
   /* translators: this is the first part of the "grab after a
    * delay of <spin button> seconds".
    */
-  label = gtk_label_new (_("Grab after a delay of"));
+  label = gtk_label_new_with_mnemonic (_("Grab _after a delay of"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
@@ -396,6 +419,7 @@ create_screenshot_frame (GtkWidget   *main_vbox,
                     G_CALLBACK (delay_spin_value_changed_cb),
                     NULL);
   gtk_box_pack_start (GTK_BOX (hbox), spin, FALSE, FALSE, 0);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin);
   gtk_widget_show (spin);
 
   /* translators: this is the last part of the "grab after a
@@ -414,13 +438,14 @@ create_interactive_dialog (void)
   GtkWidget *main_vbox;
 
   retval = gtk_dialog_new ();
+  gtk_window_set_resizable (GTK_WINDOW (retval), FALSE);
   gtk_window_set_skip_taskbar_hint (GTK_WINDOW (retval), TRUE);
   gtk_container_set_border_width (GTK_CONTAINER (retval), 5);
   gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (retval)->vbox), 2);
   gtk_window_set_title (GTK_WINDOW (retval), "");
 
   /* main container */
-  main_vbox = gtk_vbox_new (FALSE, 6);
+  main_vbox = gtk_vbox_new (FALSE, 18);
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 5);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (retval)->vbox),
                       main_vbox,
@@ -701,18 +726,22 @@ prepare_screenshot (void)
   if (initial_uri == NULL)
     {
       gchar *desktop_dir;
-      /* We failed to make a new name for the last save dir.  We try again
-       * with our home dir as a fallback.  If that fails, we don't have a
-       * place to put it. */
+
+      /* We failed to make a new name for the last save dir. We try again
+       * with our Desktop directory.
+       */
       desktop_dir = get_desktop_dir ();
       initial_uri = generate_filename_for_uri (desktop_dir);
       g_free (desktop_dir);
+    }
+
+  /* desperate fallback: /tmp */
+  if (initial_uri == NULL)
+    {
+      const gchar *tmp_dir = g_get_tmp_dir ();
+      initial_uri = generate_filename_for_uri (tmp_dir);
+    }
 
-      if (initial_uri == NULL)
-	{
-	  initial_uri = g_strdup ("file:///");
-	}
-  }
   dialog = screenshot_dialog_new (screenshot, initial_uri, take_window_shot);
   g_free (initial_uri);
 
@@ -746,7 +775,7 @@ get_desktop_dir (void)
   if (desktop_is_home_dir)
     desktop_dir = g_build_filename (g_get_home_dir (), NULL);
   else
-    desktop_dir = g_build_filename (g_get_home_dir (), "Desktop", NULL);
+    desktop_dir = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP));
 
   g_object_unref (gconf_client);
 
@@ -830,6 +859,7 @@ screenshooter_init_stock_icons (void)
 int
 main (int argc, char *argv[])
 {
+  GnomeProgram *program;
   GOptionContext *context;
   GOptionGroup *group;
   gboolean window_arg = FALSE;
@@ -865,12 +895,12 @@ main (int argc, char *argv[])
 
   gnome_authentication_manager_init ();
 
-  gnome_program_init ("gnome-screenshot", VERSION,
-		      LIBGNOMEUI_MODULE,
-		      argc, argv,
-		      GNOME_PARAM_GOPTION_CONTEXT, context,
-		      GNOME_PROGRAM_STANDARD_PROPERTIES,
-		      NULL);
+  program = gnome_program_init ("gnome-screenshot", VERSION,
+				LIBGNOMEUI_MODULE,
+				argc, argv,
+				GNOME_PARAM_GOPTION_CONTEXT, context,
+				GNOME_PROGRAM_STANDARD_PROPERTIES,
+				NULL);
   glade_gnome_init();
   gtk_window_set_default_icon_name (SCREENSHOOTER_ICON);
   screenshooter_init_stock_icons ();
@@ -900,12 +930,13 @@ main (int argc, char *argv[])
 
       dialog = create_interactive_dialog ();
       response = gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
 
       switch (response)
         {
         case GTK_RESPONSE_DELETE_EVENT:
         case GTK_RESPONSE_CANCEL:
-          g_option_context_free (context);
+          g_object_unref (program);
           return EXIT_SUCCESS;
         case GTK_RESPONSE_OK:
           break;
@@ -913,8 +944,6 @@ main (int argc, char *argv[])
           g_assert_not_reached ();
           break;
         }
-
-      gtk_widget_destroy (dialog);
     }
 
   if (delay > 0)
@@ -929,7 +958,7 @@ main (int argc, char *argv[])
       prepare_screenshot ();
     }
 
-  g_option_context_free (context);
+  g_object_unref (program);
 
   return EXIT_SUCCESS;
 }
