@@ -74,20 +74,20 @@ logview_show_version_and_quit (void)
 	exit (0);
 }
 
-static gint
+static gboolean
 save_session_cb (GnomeClient        *gnome_client,
 		 gint                phase,
 		 GnomeRestartStyle   save_style,
-		 gint                shutdown,
+		 gboolean            shutdown,
 		 GnomeInteractStyle  interact_style,
-		 gint                fast,
+		 gboolean            fast,
 		 LogviewWindow      *logview)
 {
 	gchar **argv;
 	gint numlogs;
 	GSList *logs;
 	Log *log;
-	gint i;
+	gint i = 0;
 
 	g_assert (LOGVIEW_IS_WINDOW (logview));
 	numlogs = logview_count_logs (logview);
@@ -96,7 +96,7 @@ save_session_cb (GnomeClient        *gnome_client,
 	 * and a NULL pointer to end the list
 	 */
 	argv = g_new0 (gchar *, numlogs + 2);
-	argv[0] = g_get_prgname();
+	argv[i++] = g_get_prgname();
 
 	for (logs = logview->logs; logs != NULL; logs = logs->next) {
 		Log *log = (Log *) logs->data;
@@ -105,7 +105,8 @@ save_session_cb (GnomeClient        *gnome_client,
 
 		argv[i++] = g_strdup (log->name);
 	}
-	argv[i] = NULL;
+	
+        argv[i] = NULL;
 
 	gnome_client_set_clone_command (gnome_client, numlogs + 1, argv);
 	gnome_client_set_restart_command (gnome_client, numlogs + 1, argv);
@@ -115,15 +116,6 @@ save_session_cb (GnomeClient        *gnome_client,
 	return TRUE;
 }
 
-static gint
-die_cb (GnomeClient *gnome_client,
-	gpointer     client_data)
-{
-    gtk_main_quit ();
-    
-    return 0;
-}
-
 int
 main (int argc, char *argv[])
 {
@@ -196,8 +188,6 @@ main (int argc, char *argv[])
 	if (gnome_client) {
 		g_signal_connect (gnome_client, "save_yourself",
 				  G_CALLBACK (save_session_cb), logview);
-		g_signal_connect (gnome_client, "die",
-				  G_CALLBACK (die_cb), NULL);
 	}
 
 	gtk_main ();
